@@ -1,12 +1,12 @@
 package Elastic::Model::Domain;
 {
-  $Elastic::Model::Domain::VERSION = '0.15';
+  $Elastic::Model::Domain::VERSION = '0.16';
 }
 
 use Carp;
 use Moose;
 use namespace::autoclean;
-use MooseX::Types::Moose qw(:all);
+use MooseX::Types::Moose qw(Maybe Str);
 
 #===================================
 has 'name' => (
@@ -158,7 +158,7 @@ Elastic::Model::Domain - The domain (index or alias) where your docs are stored.
 
 =head1 VERSION
 
-version 0.15
+version 0.16
 
 =head1 SYNOPSIS
 
