@@ -1,12 +1,12 @@
 package Elastic::Model::Results;
 {
-  $Elastic::Model::Results::VERSION = '0.15';
+  $Elastic::Model::Results::VERSION = '0.16';
 }
 
 use Carp;
 use Moose;
 with 'Elastic::Model::Role::Results';
-use MooseX::Types::Moose qw(:all);
+use MooseX::Types::Moose qw(Num);
 
 use namespace::autoclean;
 
@@ -36,21 +36,6 @@ sub BUILD {
     $self->_set_took( $result->{took} || 0 );
     $self->_set_facets( $result->{facets} || {} );
 
-    #$self->_set_timed_out( !!$result->{timed_out} );
-}
-
-#===================================
-sub to_cache {
-#===================================
-    my $self = shift;
-    my %data = map { $_ => $self->$_ } qw(search total max_score facets took);
-
-    my @elements = @{ $self->elements };
-    for (@elements) {
-        delete @{$_}{ '_object', '_partial' };
-    }
-    $data{elements} = \@elements;
-    return \%data;
 }
 
 1;
@@ -65,7 +50,7 @@ Elastic::Model::Results - An iterator over bounded/finite search results
 
 =head1 VERSION
 
-version 0.15
+version 0.16
 
 =head1 SYNOPSIS
 
@@ -459,19 +444,6 @@ Returns all L</elements> as a list.
 
 Also C<all_results>, C<all_objects>, C<all_elements>, C<all_partials>
 
-=head1 CACHING RESULTSETS
-
-In a later release, caching of result sets will be integrated into
-Elastic::Model.  For now, you can do this yourself with:
-
-To deflate the data for caching:
-
-    $data = $results->to_cache;
-
-To reinflate a resultset from raw data:
-
-    $results = $model->result_class->new( $data )->as_results
-
 =head1 AUTHOR
 
 Clinton Gormley <drtech@cpan.org>
