@@ -1,11 +1,11 @@
 package Elastic::Model::Role::Iterator;
 {
-  $Elastic::Model::Role::Iterator::VERSION = '0.15';
+  $Elastic::Model::Role::Iterator::VERSION = '0.16';
 }
 
 use Carp;
 use Moose::Role;
-use MooseX::Types::Moose qw(:all);
+use MooseX::Types::Moose qw(ArrayRef Int CodeRef);
 use MooseX::Attribute::Chained;
 use namespace::autoclean;
 
@@ -352,7 +352,7 @@ Elastic::Model::Role::Iterator - A generic iterator role
 
 =head1 VERSION
 
-version 0.15
+version 0.16
 
 =head1 SYNOPSIS
 
