@@ -1,6 +1,6 @@
 package Elastic::Model::Role::Results;
 {
-  $Elastic::Model::Role::Results::VERSION = '0.15';
+  $Elastic::Model::Role::Results::VERSION = '0.16';
 }
 
 use Carp;
@@ -8,7 +8,7 @@ use Moose::Role;
 
 with 'Elastic::Model::Role::Iterator';
 
-use MooseX::Types::Moose qw(:all);
+use MooseX::Types::Moose qw(HashRef Int Num CodeRef);
 use namespace::autoclean;
 
 #===================================
@@ -280,14 +280,14 @@ Elastic::Model::Role::Results - An iterator role for search results
 
 =head1 VERSION
 
-version 0.15
+version 0.16
 
 =head1 DESCRIPTION
 
 L<Elastic::Model::Role::Results> adds a number of methods and attributes
 to those provided by L<Elastic::Model::Role::Iterator> to better handle
-result sets from ElasticSearch.  It is used by L<Elastic::Model::Results>
-and by L<Elastic::Model::Results::Scrolled>.
+result sets from ElasticSearch.  It is used by L<Elastic::Model::Results>,
+L<Elastic::Model::Results::Cached> and by L<Elastic::Model::Results::Scrolled>.
 
 See those modules for more complete documentation. This module just
 documents the attributes and methods added in L<Elastic::Model::Role::Results>
