@@ -1,11 +1,11 @@
 package Elastic::Model::Scope;
 {
-  $Elastic::Model::Scope::VERSION = '0.15';
+  $Elastic::Model::Scope::VERSION = '0.16';
 }
 
 use Moose;
 use namespace::autoclean;
-use MooseX::Types::Moose qw(:all);
+use MooseX::Types::Moose qw(HashRef);
 use Scalar::Util qw(refaddr);
 use Devel::GlobalDestruction;
 
@@ -123,7 +123,7 @@ Elastic::Model::Scope - Keeps objects alive and connected
 
 =head1 VERSION
 
-version 0.15
+version 0.16
 
 =head1 DESCRIPTION
 
